#!/bin/sh
# Build a bootable floppy for the automatic installer
#
FSTYPE=ext2
if [ ! -d fs1 -o ! -d fs2 ] ; then
	echo
	echo This script must be executed in the install directory
	echo sub-directory fs1 and fs2 must be there
	echo
	exit 1
fi
sizefs1=`du fs1 | tail -1 | awk '{ print $1 }'`
sizefs2=`du fs2 | tail -1 | awk '{ print $1 }'`
echo sizefs1=$sizefs1 sizefs2=$sizefs2
# Add some space for luck
sizefs1=`expr $sizefs1 + 50`
sizefs2=`expr $sizefs2 + 500`
# Build the proper lilo.conf
echo append=\"ramdisk_start=$sizefs1 load_ramdisk=1\" >fs1/etc/lilo.conf
cat lilo.conf.end >>fs1/etc/lilo.conf
echo
echo Insert a formatted floppy.
echo It will be completly rewritten
echo It will be mounted on /mnt
echo -n insert the floppy and hit "<enter> "
read a
echo
mkfs1(){
	done=0
	if /sbin/mkfs -t $FSTYPE /dev/fd0 $sizefs1
	then
		if mount -t $FSTYPE /dev/fd0 /mnt
		then
			if cp -a fs1/. /mnt/. && /sbin/lilo -r /mnt
			then
				umount /mnt
				echo
				echo First filesystem copied successfully
				echo
				done=1
			else
				umount /mnt
			fi
		else
			echo Error while mounting on /mnt
		fi
	else
		echo Error while making first filesystem
	fi
}
mkfs2(){
	done=0
	#Insure that unused block will be 0, more maximum compression
	dd if=/dev/zero of=/dev/ram bs=1k count=$sizefs2
	if /sbin/mkfs -t $FSTYPE /dev/ram $sizefs2
	then
		if mount -t $FSTYPE /dev/ram /mnt
		then
			if cp -a fs2/. /mnt/.
			then
				umount /mnt
				dd if=/dev/ram bs=1k \
					count=$sizefs2 \
					| gzip -9 \
					| dd of=/dev/fd0 \
						bs=1k seek=$sizefs1
				echo Second filesystem copied successfully
				done=1
			else
				umount /mnt
			fi
		fi
	fi
}

mkfs1
if [ "$done" = "1" ] ; then
	mkfs2
fi
